@@ -13,12 +13,12 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d, E",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
-    Gy => "y '\N{U+0433}'. G",
-    GyMMM => "LLL y '\N{U+0433}'. G",
-    GyMMMEd => "E, d MMM y '\N{U+0433}'. G",
-    GyMMMd => "d MMM y '\N{U+0433}'. G",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
+    Gy => "y\N{U+202f}'\N{U+0433}'. G",
+    GyMMM => "LLL y\N{U+202f}'\N{U+0433}'. G",
+    GyMMMEd => "E, d MMM y\N{U+202f}'\N{U+0433}'. G",
+    GyMMMd => "d MMM y\N{U+202f}'\N{U+0433}'. G",
     GyMd => "dd.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
@@ -38,11 +38,11 @@
     MMMd => "d MMM",
     Md => "d.M",
     d => "d",
-    h => "hh a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "hh\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm.ss",
     y => "y",
     yM => "M.y",
@@ -60,12 +60,12 @@
     "yw-count-other" => "w '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' Y",
   },
   code => "be-tarask",
-  date_format_full => "EEEE, d MMMM y '\N{U+0433}'.",
-  date_format_long => "d MMMM y '\N{U+0433}'.",
-  date_format_medium => "d MMM y '\N{U+0433}'.",
+  date_format_full => "EEEE, d MMMM y\N{U+202f}'\N{U+0433}'.",
+  date_format_long => "d MMMM y\N{U+202f}'\N{U+0433}'.",
+  date_format_medium => "d MMM y\N{U+202f}'\N{U+0433}'.",
   date_format_short => "d.MM.yy",
-  datetime_format_full => "{1} '\N{U+0443}' {0}",
-  datetime_format_long => "{1} '\N{U+0443}' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -227,10 +227,10 @@
   ],
   name => "Belarusian Taraskievica orthography",
   native_language => "\N{U+0431}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+043a}\N{U+0430}\N{U+044f}",
-  native_name => "\N{U+0431}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+043a}\N{U+0430}\N{U+044f} TARASK",
+  native_name => "\N{U+0431}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+043a}\N{U+0430}\N{U+044f}",
   native_script => undef,
   native_territory => undef,
-  native_variant => "TARASK",
+  native_variant => undef,
   quarter_format_abbreviated => [
     "1-\N{U+0448}\N{U+044b} \N{U+043a}\N{U+0432}.",
     "2-\N{U+0433}\N{U+0456} \N{U+043a}\N{U+0432}.",
@@ -274,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => "Taraskievica orthography",
-  version => 41,
+  version => 44,
 }
