@@ -13,8 +13,8 @@
     EHm => "E HH.mm",
     EHms => "E HH.mm.ss",
     Ed => "E 'den' d.",
-    Ehm => "E h.mm a",
-    Ehms => "E h.mm.ss a",
+    Ehm => "E h.mm\N{U+202f}a",
+    Ehms => "E h.mm.ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E d. MMM y G",
@@ -37,11 +37,11 @@
     MMdd => "dd.MM",
     Md => "d.M",
     d => "d.",
-    h => "h a",
-    hm => "h.mm a",
-    hms => "h.mm.ss a",
-    hmsv => "h.mm.ss a v",
-    hmv => "h.mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h.mm\N{U+202f}a",
+    hms => "h.mm.ss\N{U+202f}a",
+    hmsv => "h.mm.ss\N{U+202f}a v",
+    hmv => "h.mm\N{U+202f}a v",
     ms => "mm.ss",
     y => "y",
     yM => "M.y",
@@ -62,15 +62,15 @@
   date_format_long => "d. MMMM y",
   date_format_medium => "d. MMM y",
   date_format_short => "dd.MM.y",
-  datetime_format_full => "{1} 'kl'. {0}",
-  datetime_format_long => "{1} 'kl'. {0}",
+  datetime_format_full => "{1} {0}",
+  datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "man.",
-    "tir.",
+    "tirs.",
     "ons.",
-    "tor.",
+    "tors.",
     "fre.",
     "l\N{U+00f8}r.",
     "s\N{U+00f8}n.",
@@ -94,13 +94,13 @@
     "s\N{U+00f8}ndag",
   ],
   day_stand_alone_abbreviated => [
-    "man",
-    "tir",
-    "ons",
-    "tor",
-    "fre",
-    "l\N{U+00f8}r",
-    "s\N{U+00f8}n",
+    "man.",
+    "tirs.",
+    "ons.",
+    "tors.",
+    "fre.",
+    "l\N{U+00f8}r.",
+    "s\N{U+00f8}n.",
   ],
   day_stand_alone_narrow => [
     "M",
@@ -129,8 +129,8 @@
     "eKr",
   ],
   era_wide => [
-    "f.Kr.",
-    "e.Kr.",
+    "f\N{U+00f8}r Kristus",
+    "efter Kristus",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %e %b %H:%M:%S %Z %Y",
@@ -272,5 +272,5 @@
   time_format_medium => "HH.mm.ss",
   time_format_short => "HH.mm",
   variant => undef,
-  version => 41,
+  version => 44,
 }
