@@ -14,9 +14,12 @@
     EHms => "E HH:mm:ss",
     Ed => "E d",
     Ehm => "E h:mm\N{U+202f}a",
+    "Ehm-alt-ascii" => "E h:mm a",
     Ehms => "E h:mm:ss\N{U+202f}a",
+    "Ehms-alt-ascii" => "E h:mm:ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
+    GyMMMEEEEd => "EEEE d MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
     GyMd => "d/M/y GGGGG",
@@ -28,7 +31,9 @@
     M => "L",
     MEd => "E, d/M",
     MMM => "LLL",
+    MMMEEEEd => "EEEE d MMM",
     MMMEd => "E, d MMM",
+    MMMMEEEEd => "EEEE d MMMM",
     "MMMMW-count-one" => "'week' W 'of' MMMM",
     "MMMMW-count-other" => "'week' W 'of' MMMM",
     MMMMd => "d MMMM",
@@ -37,17 +42,24 @@
     Md => "d/M",
     d => "d",
     h => "h\N{U+202f}a",
+    "h-alt-ascii" => "h a",
     hm => "h:mm\N{U+202f}a",
+    "hm-alt-ascii" => "h:mm a",
     hms => "h:mm:ss\N{U+202f}a",
+    "hms-alt-ascii" => "h:mm:ss a",
     hmsv => "h:mm:ss\N{U+202f}a v",
+    "hmsv-alt-ascii" => "h:mm:ss a v",
     hmv => "h:mm\N{U+202f}a v",
+    "hmv-alt-ascii" => "h:mm a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM/y",
     yMEd => "E, dd/MM/y",
     yMMM => "MMM y",
+    yMMMEEEEd => "EEEE d MMM y",
     yMMMEd => "E, d MMM y",
     yMMMM => "MMMM y",
+    yMMMMEEEEd => "EEEE d MMMM y",
     yMMMd => "d MMM y",
     yMd => "dd/MM/y",
     yQQQ => "QQQ y",
@@ -56,7 +68,7 @@
     "yw-count-other" => "'week' w 'of' Y",
   },
   code => "en-AU",
-  date_format_full => "EEEE, d MMMM y",
+  date_format_full => "EEEE d MMMM y",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "d/M/yy",
@@ -101,13 +113,13 @@
     "Sun",
   ],
   day_stand_alone_narrow => [
-    "M.",
-    "Tu.",
-    "W.",
-    "Th.",
-    "F.",
-    "Sa.",
-    "Su.",
+    "M",
+    "T",
+    "W",
+    "T",
+    "F",
+    "S",
+    "S",
   ],
   day_stand_alone_wide => [
     "Monday",
@@ -185,8 +197,8 @@
     "Mar",
     "Apr",
     "May",
-    "Jun",
-    "Jul",
+    "June",
+    "July",
     "Aug",
     "Sept",
     "Oct",
@@ -270,5 +282,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 42,
+  version => 44,
 }
