@@ -137,7 +137,7 @@
   glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%H:%M:%S",
-  language => "Fulah",
+  language => "Fula",
   month_format_abbreviated => [
     "sii",
     "col",
@@ -222,10 +222,10 @@
     "jolal",
     "bowte",
   ],
-  name => "Fulah Ghana Latin",
+  name => "Fula Ghana Latin",
   native_language => "Pulaar",
-  native_name => "Pulaar Ganaa Latn",
-  native_script => "Latn",
+  native_name => "Pulaar Ganaa",
+  native_script => undef,
   native_territory => "Ganaa",
   native_variant => undef,
   quarter_format_abbreviated => [
@@ -266,10 +266,10 @@
   ],
   script => "Latin",
   territory => "Ghana",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 41,
+  version => 44,
 }
