@@ -13,12 +13,13 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "ccc, d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
-    Gy => "y '\N{U+0433}'. G",
-    GyMMM => "LLL y G",
-    GyMMMEd => "E, d MMM y '\N{U+0433}'. G",
-    GyMMMd => "d MMM y '\N{U+0433}'. G",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
+    Gy => "y\N{U+202f}'\N{U+0433}'. G",
+    GyMMM => "LLL y\N{U+202f}'\N{U+0433}'. G",
+    GyMMMEd => "E, d MMM y\N{U+202f}'\N{U+0433}'. G",
+    GyMMMd => "d MMM y\N{U+202f}'\N{U+0433}'. G",
+    GyMd => "dd.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -37,32 +38,32 @@
     MMdd => "dd.MM",
     Md => "dd.MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM.y",
-    yMEd => "ccc, dd.MM.y '\N{U+0433}'.",
+    yMEd => "ccc, dd.MM.y\N{U+202f}'\N{U+0433}'.",
     yMM => "MM.y",
-    yMMM => "LLL y '\N{U+0433}'.",
-    yMMMEd => "E, d MMM y '\N{U+0433}'.",
-    yMMMM => "LLLL y '\N{U+0433}'.",
-    yMMMd => "d MMM y '\N{U+0433}'.",
+    yMMM => "LLL y\N{U+202f}'\N{U+0433}'.",
+    yMMMEd => "E, d MMM y\N{U+202f}'\N{U+0433}'.",
+    yMMMM => "LLLL y\N{U+202f}'\N{U+0433}'.",
+    yMMMd => "d MMM y\N{U+202f}'\N{U+0433}'.",
     yMd => "dd.MM.y",
-    yQQQ => "QQQ y '\N{U+0433}'.",
-    yQQQQ => "QQQQ y '\N{U+0433}'.",
+    yQQQ => "QQQ y\N{U+202f}'\N{U+0433}'.",
+    yQQQQ => "QQQQ y\N{U+202f}'\N{U+0433}'.",
     "yw-count-few" => "w-'\N{U+044f}' '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044f}' Y '\N{U+0433}'.",
     "yw-count-many" => "w-'\N{U+044f}' '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044f}' Y '\N{U+0433}'.",
     "yw-count-one" => "w-'\N{U+044f}' '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044f}' Y '\N{U+0433}'.",
     "yw-count-other" => "w-'\N{U+044f}' '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044f}' Y '\N{U+0433}'.",
   },
   code => "ru",
-  date_format_full => "EEEE, d MMMM y '\N{U+0433}'.",
-  date_format_long => "d MMMM y '\N{U+0433}'.",
-  date_format_medium => "d MMM y '\N{U+0433}'.",
+  date_format_full => "EEEE, d MMMM y\N{U+202f}'\N{U+0433}'.",
+  date_format_long => "d MMMM y\N{U+202f}'\N{U+0433}'.",
+  date_format_medium => "d MMM y\N{U+202f}'\N{U+0433}'.",
   date_format_short => "dd.MM.y",
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
@@ -78,13 +79,13 @@
     "\N{U+0432}\N{U+0441}",
   ],
   day_format_narrow => [
-    "\N{U+043f}\N{U+043d}",
-    "\N{U+0432}\N{U+0442}",
-    "\N{U+0441}\N{U+0440}",
-    "\N{U+0447}\N{U+0442}",
-    "\N{U+043f}\N{U+0442}",
-    "\N{U+0441}\N{U+0431}",
-    "\N{U+0432}\N{U+0441}",
+    "\N{U+041f}",
+    "\N{U+0412}",
+    "\N{U+0421}",
+    "\N{U+0427}",
+    "\N{U+041f}",
+    "\N{U+0421}",
+    "\N{U+0412}",
   ],
   day_format_wide => [
     "\N{U+043f}\N{U+043e}\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044c}\N{U+043d}\N{U+0438}\N{U+043a}",
@@ -274,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 44,
 }
